@@ -5,7 +5,7 @@ use Encode qw(decode);
 use base 'Exporter';
 our @EXPORT = qw(convert_to_ascii);
 our @EXPORT_OK = qw(convert_to_ascii);
-our $VERSION = '0.27';
+our $VERSION = '0.28';
 my %char_map;
 
 =encoding utf8
@@ -950,40 +950,40 @@ __DATA__
 075E 45
 075F 45
 076B 6A
-07C0 6F
+07C0 30
 07CA 6C
 07F4 27
 07F5 27
 07FA 5F
 0903 3A
-0966 6F
+0966 30
 097D 3F
-09E6 6F
+09E6 30
 09EA 38
 09ED 39
-0A66 6F
+0A66 30
 0A67 39
 0A6A 38
 0A83 3A
-0AE6 6F
+0AE6 30
 0B03 38
 0B20 4F
-0B66 6F
+0B66 30
 0B68 39
 0BD0 43
-0BE6 6F
+0BE6 30
 0C02 6F
-0C66 6F
+0C66 30
 0C82 6F
-0CE6 6F
+0CE6 30
 0D02 6F
 0D20 6F
-0D66 6F
+0D66 30
 0D82 6F
-0E50 6F
-0ED0 6F
+0E50 30
+0ED0 30
 101D 6F
-1040 6F
+1040 30
 10A6 42
 10AF 34
 10CD 5A
@@ -1706,7 +1706,7 @@ __DATA__
 2057 27+27+27+27
 205A 3A
 205F 20
-2070 4F
+2070 30
 2071 69
 2074 34
 2075 35
@@ -1720,7 +1720,7 @@ __DATA__
 207D 28
 207E 29
 207F 6E
-2080 4F
+2080 30
 2081 31
 2082 32
 2083 33
@@ -2280,7 +2280,7 @@ __DATA__
 2F03 2F
 3000 20
 3003 22
-3007 4F
+3007 30
 3008 3C
 3009 3E
 300A 3C+3C
@@ -2728,7 +2728,7 @@ FF0C 2C
 FF0D 2D
 FF0E 2E
 FF0F 2F
-FF10 4F
+FF10 30
 FF11 31
 FF12 32
 FF13 33
@@ -4097,7 +4097,7 @@ FFEE 6F
 1F7BE 2A
 1F7BF 2A
 1FBC4 5B+3F+5D
-1FBF0 4F
+1FBF0 30
 1FBF1 31
 1FBF2 32
 1FBF3 33
